# mypy-boto3-budgets

[![PyPI - mypy-boto3-budgets](https://img.shields.io/pypi/v/mypy-boto3-budgets.svg?color=blue)](https://pypi.org/project/mypy-boto3-budgets)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-budgets.svg?color=blue)](https://pypi.org/project/mypy-boto3-budgets)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)

Type annotations for
[boto3.Budgets 1.12.18](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/budgets.html#Budgets) service
compatible with [mypy](https://github.com/python/mypy), [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/) and other tools.

Generated by [mypy-boto3-buider 1.0.5](https://github.com/vemel/mypy_boto3_builder).

More information can be found on [boto3-stubs](https://pypi.org/project/boto3-stubs/) page.

- [mypy-boto3-budgets](#mypy-boto3-budgets)
  - [How to use](#how-to-use)
    - [Type checking](#type-checking)
  - [How it works](#how-it-works)

## How to use

### Type checking

Make sure you have [mypy](https://github.com/python/mypy) installed and activated in your IDE.

Install `boto3-stubs` for `Budgets` service.

```bash
python -m pip install boto3-stubs[mypy-boto3-budgets]
```

Use `boto3` with `mypy_boto3` in your project and enjoy type checking and auto-complete.

```python
import boto3

from mypy_boto3 import budgets
# alternative import if you do not want to install mypy_boto3 package
# import mypy_boto3_budgets as budgets

# Use this client as usual, now mypy can check if your code is valid.
# Check if your IDE supports function overloads,
# you probably do not need explicit type annotations
# client = boto3.client("budgets")
client: budgets.BudgetsClient = boto3.client("budgets")

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: budgets.BudgetsClient = session.client("budgets")


# Paginators need type annotation on creation
describe_budgets_paginator: budgets.DescribeBudgetsPaginator = client.get_paginator("describe_budgets")
describe_notifications_for_budget_paginator: budgets.DescribeNotificationsForBudgetPaginator = client.get_paginator("describe_notifications_for_budget")
describe_subscribers_for_notification_paginator: budgets.DescribeSubscribersForNotificationPaginator = client.get_paginator("describe_subscribers_for_notification")
```

## How it works

Fully automated [builder](https://github.com/vemel/mypy_boto3_builder) carefully generates
type annotations for each service, patiently waiting for `boto3` updates. It delivers
a drop-in type annotations for you and makes sure that:

- All available `boto3` services are covered.
- Each public class and method of every `boto3` service gets valid type annotations
  extracted from the documentation (blame `botocore` docs if types are incorrect).
- Type annotations include up-to-date documentation.
- Link to documentation is provided for every method.
- Code is processed by [black](https://github.com/psf/black) for readability.